==> opennebula-6.99.85-1-amd64.tar.gz: opennebula-6.99.85/src/fireedge/src/modules/features/middleware.js <==
/* ------------------------------------------------------------------------- *
 * Copyright 2002-2025, OpenNebula Project, OpenNebula Systems               *
 *                                                                           *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may   *
 * not use this file except in compliance with the License. You may obtain   *
 * a copy of the License at                                                  *
 *                                                                           *
 * http://www.apache.org/licenses/LICENSE-2.0                                *
 *                                                                           *
 * Unless required by applicable law or agreed to in writing, software       *
 * distributed under the License is distributed on an "AS IS" BASIS,         *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  *
 * See the License for the specific language governing permissions and       *
 * limitations under the License.                                            *
 * ------------------------------------------------------------------------- */
import { isRejectedWithValue, Middleware, Dispatch } from '@reduxjs/toolkit'

import { oneApi } from '@modules/features/OneApi'
import { AuthSlice, logout } from '@modules/features/Auth/slice'
import { T, ONEADMIN_GROUP_ID } from '@ConstantsModule'
const { name: authName } = AuthSlice

/**
 * @param {{ dispatch: Dispatch }} params - Redux parameters
 * @returns {Middleware} - Unauthenticated middleware
 */
export const unauthenticatedMiddleware =
  ({ dispatch }) =>
  (next) =>
  (action) => {
    if (
      oneApi.endpoints.getAuthUser.matchRejected(action) ||
      (isRejectedWithValue(action) && action.payload.status === 401)
    ) {
      dispatch(logout(T.SessionExpired))
    }

    return next(action)
  }

/**
 * @param {{ dispatch: Dispatch, getState: function():object }} params - Redux parameters
 * @returns {Middleware} - Middleware to logout when user isn't in oneadmin group
 */
export const onlyForOneadminMiddleware =
  ({ dispatch, getState }) =>
  (next) =>
  (action) => {
    const groups = getState()?.[authName]?.user?.GROUPS?.ID

    if (!logout.match(action) && !!groups?.length) {
      const ensuredGroups = [groups].flat()

      !ensuredGroups.includes(ONEADMIN_GROUP_ID) &&
        dispatch(logout(T.OnlyForOneadminGroup))
    }

    return next(action)
  }

==> opennebula-7.1.80-1-amd64.tar.gz: opennebula-7.1.80/src/fireedge/src/modules/features/middleware.js <==
/* ------------------------------------------------------------------------- *
 * Copyright 2002-2025, OpenNebula Project, OpenNebula Systems               *
 *                                                                           *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may   *
 * not use this file except in compliance with the License. You may obtain   *
 * a copy of the License at                                                  *
 *                                                                           *
 * http://www.apache.org/licenses/LICENSE-2.0                                *
 *                                                                           *
 * Unless required by applicable law or agreed to in writing, software       *
 * distributed under the License is distributed on an "AS IS" BASIS,         *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  *
 * See the License for the specific language governing permissions and       *
 * limitations under the License.                                            *
 * ------------------------------------------------------------------------- */
import { Middleware } from '@reduxjs/toolkit'
import { logout } from '@modules/features/Auth/slice'
import { oneApi } from '@modules/features/OneApi'
import { T } from '@ConstantsModule'

/**
 * @param {object} store - Redux store
 * @returns {Middleware} - Unauthenticated middleware
 */
export const unauthenticatedMiddleware = (store) => (next) => {
  const { getState, dispatch } = store
  let canResetCache = true

  return (action) => {
    const { auth } = getState()
    const status = action?.payload?.status

    if (status != null) {
      if (status === 401 && canResetCache) {
        canResetCache = false
        dispatch(logout(auth?.isLoggedIn ? T.SessionExpired : undefined)) // Expired = true
        dispatch(oneApi.util.resetApiState()) // Expired = false
      } else if (status !== 401) {
        canResetCache = true
      }
    }

    return next(action)
  }
}
